%% get depth for perspective camera 
%
% Usage:
%   d = calc_depth_perspective(X,P)
%
%   X  - 4-vector of 3D points
%   P  - 3x4 matrix of perspective projection
%
%   d  - depth, is positive if point is in front of camera
% 
% Wolfgang Frstner 4/2013
% wfoerstn@uni-bonn.de 
%
% See also calc_depth_central_x, calc_depth_central_xs, calc_depth_central_xs_RZ


function depth = calc_depth_perspective(X,P)

% w'-coordinate = P(3,:)*X 
% normalization with 
%      determinant |A|, 
%      length of vector of viewing direction, 
%      homogeneous coord of X
%
depth = -P(3,:) * X * det(P(:,1:3)) / (norm(P(3,1:3)) * X(4));
